==> blobAndConquer-0.1-1.tar.gz: BlobAndConquer/src/features.h <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void faceTarget(Unit *unit);
extern void attackTarget(Unit *unit);
extern void enemyWalkToTarget(Unit *unit);
extern void throwFleshChunk(float x, float y, float z);
extern void throwSpawnedItem(Entity *item);
extern Unit *addEnemy(Properties *props);
extern void addTeleportParticles(Vector position);
extern void addTeleporterParticle(Vector position);
extern void drawCyclinder(Vector position, int segments, float size, float height, GLColor c);
extern void showMessageDialog(char *message, char *buttonLabel);
extern bool saveGame();
extern void teleportUnit();
extern void blobsRunToBob();
extern bool showSecurityDialog(char *code);
extern void faceLocation(Unit *unit, Vector location);
extern bool withinViewableRange(Vector position, float size);

extern Audio *audio;
extern BoundingBoxManager *bbManager;
extern Camera *camera;
extern EntityManager *entityManager;
extern Engine *engine;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern RandomNameGenerator *randomNameGenerator;
extern Unit *player;

extern Entity *self;

==> blobAndConquer-0.2-1.tar.gz: BlobAndConquer/src/features.h <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void faceTarget(Unit *unit);
extern void attackTarget(Unit *unit);
extern void enemyWalkToTarget(Unit *unit);
extern void throwFleshChunk(float x, float y, float z);
extern void throwSpawnedItem(Entity *item);
extern Unit *addEnemy(Properties *props);
extern Unit *addBlob(Properties *props);
extern void addTeleportParticles(Vector position);
extern void addTeleporterParticle(Vector position);
extern void drawCyclinder(Vector position, int segments, float size, float height, GLColor c);
extern void showMessageDialog(char *message, char *buttonLabel);
extern bool saveGame();
extern void teleportUnit();
extern void blobsRunToBob();
extern bool showSecurityDialog(char *code);
extern void faceLocation(Unit *unit, Vector location);
extern bool withinViewableRange(Entity *entity);

extern Audio *audio;
extern BoundingBoxManager *bbManager;
extern Camera *camera;
extern EntityManager *entityManager;
extern Engine *engine;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern RandomNameGenerator *randomNameGenerator;
extern TextureManager *textureManager;
extern Unit *player;

extern Entity *self;
